==> hats_import-0.3.6b0.tar.gz: hats_import-0.3.6b0/tests/hats_import/verification/test_verification_arguments.py <==
"""Tests of argument validation"""

import pytest
from hats.catalog import Catalog

from hats_import.verification.arguments import VerificationArguments


def test_none():
    """No arguments provided. Should error for required args."""
    with pytest.raises(ValueError):
        VerificationArguments()


def test_empty_required(tmp_path):
    """*Most* required arguments are provided."""
    ## Input path is missing
    with pytest.raises(ValueError, match="input_catalog_path"):
        VerificationArguments(
            output_path=tmp_path,
            output_artifact_name="small_sky_object_verification_report",
        )


def test_invalid_paths(tmp_path, small_sky_object_catalog):
    """Required arguments are provided, but paths aren't found."""
    ## Prove that it works with required args
    VerificationArguments(
        input_catalog_path=small_sky_object_catalog,
        output_path=tmp_path,
        output_artifact_name="small_sky_object_verification_report",
    )

    ## Input path is invalid catalog
    with pytest.raises(ValueError, match="input_catalog_path not a valid catalog"):
        VerificationArguments(
            input_catalog_path="path",
            output_path=f"{tmp_path}/path",
            output_artifact_name="small_sky_object_verification_report",
        )


def test_good_paths(tmp_path, small_sky_object_catalog):
    """Required arguments are provided, and paths are found."""
    tmp_path_str = str(tmp_path)
    args = VerificationArguments(
        input_catalog_path=small_sky_object_catalog,
        output_path=tmp_path,
        output_artifact_name="small_sky_object_verification_report",
    )
    assert args.input_catalog_path == small_sky_object_catalog
    assert str(args.output_path) == tmp_path_str
    assert str(args.tmp_path).startswith(tmp_path_str)


@pytest.mark.timeout(5)
def test_catalog_object(tmp_path, small_sky_object_catalog):
    """Required arguments are provided, and paths are found.

    NB: This is currently the last test in alpha-order, and may require additional
    time to teardown fixtures."""
    small_sky_catalog_object = Catalog.read_hats(catalog_path=small_sky_object_catalog)
    tmp_path_str = str(tmp_path)
    args = VerificationArguments(
        input_catalog=small_sky_catalog_object,
        output_path=tmp_path,
        output_artifact_name="small_sky_object_verification_report",
    )
    assert args.input_catalog_path == small_sky_object_catalog
    assert str(args.output_path) == tmp_path_str
    assert str(args.tmp_path).startswith(tmp_path_str)

==> hats_import-0.4.3.tar.gz: hats_import-0.4.3/tests/hats_import/verification/test_verification_arguments.py <==
"""Tests of argument validation"""

import pytest
from hats import read_hats

from hats_import.verification.arguments import VerificationArguments


def test_none():
    """No arguments provided. Should error for required args."""
    with pytest.raises(ValueError):
        VerificationArguments()


def test_empty_required(tmp_path):
    """*Most* required arguments are provided."""
    ## Input path is missing
    with pytest.raises(ValueError, match="input_catalog_path"):
        VerificationArguments(
            output_path=tmp_path,
            output_artifact_name="small_sky_object_verification_report",
        )


def test_invalid_paths(tmp_path, small_sky_object_catalog):
    """Required arguments are provided, but paths aren't found."""
    ## Prove that it works with required args
    VerificationArguments(
        input_catalog_path=small_sky_object_catalog,
        output_path=tmp_path,
        output_artifact_name="small_sky_object_verification_report",
    )

    ## Input path is invalid catalog
    with pytest.raises(ValueError, match="input_catalog_path not a valid catalog"):
        VerificationArguments(
            input_catalog_path="path",
            output_path=f"{tmp_path}/path",
            output_artifact_name="small_sky_object_verification_report",
        )


def test_good_paths(tmp_path, small_sky_object_catalog):
    """Required arguments are provided, and paths are found."""
    tmp_path_str = str(tmp_path)
    args = VerificationArguments(
        input_catalog_path=small_sky_object_catalog,
        output_path=tmp_path,
        output_artifact_name="small_sky_object_verification_report",
    )
    assert args.input_catalog_path == small_sky_object_catalog
    assert str(args.output_path) == tmp_path_str
    assert str(args.tmp_path).startswith(tmp_path_str)


@pytest.mark.timeout(5)
def test_catalog_object(tmp_path, small_sky_object_catalog):
    """Required arguments are provided, and paths are found.

    NB: This is currently the last test in alpha-order, and may require additional
    time to teardown fixtures."""
    small_sky_catalog_object = read_hats(catalog_path=small_sky_object_catalog)
    tmp_path_str = str(tmp_path)
    args = VerificationArguments(
        input_catalog=small_sky_catalog_object,
        output_path=tmp_path,
        output_artifact_name="small_sky_object_verification_report",
    )
    assert args.input_catalog_path == small_sky_object_catalog
    assert str(args.output_path) == tmp_path_str
    assert str(args.tmp_path).startswith(tmp_path_str)
